searchData={"items":[{"type":"module","title":"MbtaMetro","doc":"A Phoenix LiveView component library.","ref":"MbtaMetro.html"},{"type":"module","title":"MbtaMetro.Live.DatePicker","doc":"A live component that renders a date picker using Flatpickr.\n\nYou must pass in the following assigns:\n\n  * `:field` - A form field struct retrieved from a form, for example: @form[:datetime].\n\nYou can optionally pass in a `:config` map:\n  * `:default_date` - The default date that should be selected.\n  * `:enable_time` - A boolean that determines if the time picker should be enabled.\n  * `:max_date` - The maximum date that can be selected.\n  * `:min_date` - The minimum date that can be selected.","ref":"MbtaMetro.Live.DatePicker.html"},{"type":"function","title":"MbtaMetro.Live.DatePicker.handle_event/3","doc":"When we get an event to set the dateime, we push the event to the socket.\nThis will be picked up by the Hook.","ref":"MbtaMetro.Live.DatePicker.html#handle_event/3"},{"type":"function","title":"MbtaMetro.Live.DatePicker.mount/3","doc":"","ref":"MbtaMetro.Live.DatePicker.html#mount/3"},{"type":"function","title":"MbtaMetro.Live.DatePicker.render/1","doc":"Renders the date picker component.","ref":"MbtaMetro.Live.DatePicker.html#render/1"},{"type":"module","title":"MbtaMetro.Live.Map","doc":"A live component that renders a map using [maplibre-gl](https://maplibre.org/maplibre-gl-js/docs/).\n\nYou can optionally pass in the following assigns:\n\n  * `:class` - The CSS classes to apply to the map container. You'll most likely want to set the height and width of the map here.\n  * `:config` - The maplibre gl configuration.\n  * `:click_handler` - A boolean indicating whether to handle map clicks.\n  * `:lines` - A list of lists of coordinates to draw lines on the map. Each list of coordinates should be a list of two numbers: the longitude and latitude.\n  * `:pins` - A list of coordinates to place pins on the map. Each coordinate should be a list of two numbers: the longitude and latitude.\n  * `:points` - A list of coordinates to place points on the map. Each coordinate should be a list of two numbers: the longitude and latitude.\n\nIf `:click_handler` is `true`, the component will send a `map-clicked` event to the parent live view when the map is clicked.\n\n`pins` will be assigned a letter A-Z for each marker added to the map. E.g., 0 => A, 1 => B, etc.","ref":"MbtaMetro.Live.Map.html"},{"type":"function","title":"MbtaMetro.Live.Map.handle_event/3","doc":"The map has to be loaded before we can draw anything on it.\nOnce the Hook tells us it has loaded, we tell it to update the lines and markers.\nWe then update the `loaded` assign to `true` so we know future updates can be drawn on the map.","ref":"MbtaMetro.Live.Map.html#handle_event/3"},{"type":"function","title":"MbtaMetro.Live.Map.render/1","doc":"There are three main sections of the map component.\nThe container will hold the map itself.\nThe lines will hold the lines to draw on the map.\nThe markers will hold the points and pins to place on the map.\n\nThe associated Hook will take the lines and markers and draw them on the map.","ref":"MbtaMetro.Live.Map.html#render/1"},{"type":"function","title":"MbtaMetro.Live.Map.update/2","doc":"We check if the map is loaded; if so, we tell the Hook to update the lines and markers every time the component updates.\nIf the map is not loaded, we check for for assigns and assign defaults for any not passed into the component.","ref":"MbtaMetro.Live.Map.html#update/2"},{"type":"module","title":"MbtaMetroWeb.Live.Demo","doc":"","ref":"MbtaMetroWeb.Live.Demo.html"},{"type":"function","title":"MbtaMetroWeb.Live.Demo.render/1","doc":"","ref":"MbtaMetroWeb.Live.Demo.html#render/1"},{"type":"task","title":"mix mbta_metro.export_assets","doc":"Exports assets to the priv/static directory","ref":"Mix.Tasks.MbtaMetro.ExportAssets.html"},{"type":"task","title":"mix mbta_metro.update_assets","doc":"Updates the assets of MbtaMetro based on the version","ref":"Mix.Tasks.MbtaMetro.UpdateAssets.html"},{"type":"task","title":"mix mbta_metro.version","doc":"Update the version of MbtaMetro","ref":"Mix.Tasks.MbtaMetro.Version.html"},{"type":"extras","title":"MBTA METRO","doc":"# MBTA METRO\n\n[![hex version](https://img.shields.io/hexpm/v/mbta_metro.svg)](https://hex.pm/packages/mbta_metro)\n\nThis package contains function components, live components, and default styles.\n\nTo demo all of the `mbta_metro` components:\n\n```\n%> npm install --prefix assets\n%> mix deps.get\n%> mix phx.server\n```\n\nNow you can visit [`http://localhost:4000`](http://localhost:4000/storybook) from your browser.","ref":"readme.html"},{"type":"extras","title":"Installation - MBTA METRO","doc":"","ref":"readme.html#installation"},{"type":"extras","title":"Install Tailwind - MBTA METRO","doc":"If you have a clean, recent installation of Phoenix, you should already have Tailwind installed.\nIf not, you can follow [this guide](https://tailwindcss.com/docs/guides/phoenix).","ref":"readme.html#install-tailwind"},{"type":"extras","title":"Install MBTA METRO - MBTA METRO","doc":"Add this to your `mix.exs`:\n\n```elixir\ndef deps do\n  [\n    {:mbta_metro, \">= 0.0.0\"}\n  ]\nend\n```\n\nImport `mbta_metro`'s styles in your `assets/css/app.css`:\n\n```css\n@import \"../../deps/mbta_metro/priv/static/assets/default.css\";\n```\n\nMake sure your assets are in line with the hex version of `mbta_metro`:\n\n```\n%> mix mbta_metro.update_assets\n```\n\nYou can then use some defaults in your `assets/tailwind.config.js`:\n\n```js\nconst {colors, content, fontFamily, plugins, safelist} = require(\"mbta_metro\")\n\nmodule.exports = {\n  content: [\n    ...content,\n  ],\n  safelist: [\n    ...safelist,\n  ],\n  plugins: [\n    ...plugins(), // Note that this is a function\n  ],\n  theme: {\n    extend: {\n      colors: {\n        ...colors\n      }\n    },\n    fontFamily: {\n      ...fontFamily,\n    },\n  }\n}\n```\n\nIf you want to use `mbta_metro`'s LiveComponents, you'll need to add its hooks in your `assets/js/app.js`:\n\n```js\nimport {Hooks} from \"mbta_metro\"\n\nlet liveSocket = new LiveSocket(\"/live\", Socket, {\n  hooks: {\n    ...Hooks\n  }\n})\n```\n\nIf you want to include hooks individually, you can do so:\n\n```js\nimport {Map} from \"mbta_metro\"\n\nlet liveSocket = new LiveSocket(\"/live\", Socket, {\n  hooks: {\n    Map\n  }\n})\n```","ref":"readme.html#install-mbta-metro"},{"type":"extras","title":"Custom Icons - MBTA METRO","doc":"Along with all of the [free Font Awesome icons](https://fontawesome.com/icons), you can add custom icons by pointing to any directory you like. E.g.,\n\n```elixir\nconfig :mbta_metro, custom_icons: \"#{File.cwd!()}/priv/static/icons/your-directory/your-icon.svg\"\n```\n\nSVGs in the above directory will be turned into icons and can be used as follows:\n\n```\n<.icon type=\"your-directory\" name=\"your-icon\" class=\"...\" />\n```","ref":"readme.html#custom-icons"},{"type":"extras","title":"LiveComponents - MBTA METRO","doc":"Some components, like the Map, take further configuration.\n\n#### Map\n\nThe map components uses [maplibre-gl](https://maplibre.org/maplibre-gl-js/docs/) so you must pass in config with a valid [style spec](https://maplibre.org/maplibre-style-spec/).\n\nYou can use an external style source.\n\n```elixir\n@api_key = Application.compile_env!(\"MBTA_METRO_MAP_API_KEY\")\n\nconfig :mbta_metro, :map, %{\n  style: \"https://tiles.stadiamaps.com/styles/alidade_smooth.json?api_key=#{@api_key}\"\n}\n```\n\nIf you do use an external source you'll have to make sure it is defined in your CSP (assuming you have one):\n\n```elixir\n[\n  \"child-src blob: ;\",\n  \"connect-src *.stadiamaps.com\",\n  \"worker-src blob: ;\"\n]\n```\n\nOr, you can define your own style.\n\n```elixir\nconfig :mbta_metro, :map, config: %{\n  center: [-71.0589, 42.3601],\n  style: %{\n    \"version\" => 8,\n    \"sources\" => %{...},\n    \"layers\" => %{...}\n  },\n  zoom: 15\n}\n```","ref":"readme.html#livecomponents"},{"type":"extras","title":"Production usage - MBTA METRO","doc":"Because we ship Mbta Metro's javascript via hex and not npm, installing the library works a little differently than normal.\nWe included a mix task `mix mbta_metro.update_assets` that will install the javascript along with its dependencies in the normal Phoenix `node_modules` directory.\nWhen you go to build and compile your application you might run into errors about Mbta Metro's dependencies not being found.\nIf you are building in an environment where you have Elixir and Node in the same image, you can simply run the above mix task.\nIf you only have Node in the image, you can run the underlying npm command that mix tasks calls:\n\n```\n%> npm install --prefix assets -S -install-links deps/mbta_metro/priv/\n```","ref":"readme.html#production-usage"},{"type":"extras","title":"Publishing - MBTA METRO","doc":"You can publish a new release with a single script:\n\n```\n%> git checkout main\n%> git pull origin main\n%> ./release\nPlease enter a release level [patch | minor | major]: patch\n...\n%> git push origin main\n```","ref":"readme.html#publishing"}],"content_type":"text/markdown","producer":{"name":"ex_doc","version":[48,46,51,52,46,50]}}